
##########
skconfig
##########
Package ``skconfig`` provides an interface for managing YAML based configuration files. The package provides a few
extensions to help ease access and usage of the configuration file,

#.  The ability to load and save configuration files in standard locations on the computer.
#.  A *dot* or *slash* notation to index nested keys
#.  A simple macro scheme which allows the value of one key or environment variables to be used when fetching another value.


..  toctree::
    :maxdepth: 1

    installation
    overview
    api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
